@@ -309,7 +309,7 @@ class BaseHandler(RequestHandler):
                         value = unquote(value)
                     if key == "roleIds" and value and isinstance(value, str):
                         user_info[key] = json.loads(value)
-                    setattr(user, key, value)
+                    setattr(user, key, user_info[key])
 
                 return user
         return None
